==> ejc-bpmdesktop-api-3.0.0-20230403.034041-49-sources.jar: com/ejianc/business/desktop/vo/UserInfoVO.java <==
package com.ejianc.business.desktop.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 流程主题门户接口
 * 
 * @author generator
 * 
 */
public class UserInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String materialCategoryName;
    private Long num;
    private  Long amount;
    private String weight;
    private String materialUnitName;
    private String[] strings1;
    private Double[] doubles1;


    public String[] getStrings1() {
        return strings1;
    }

    public void setStrings1(String[] strings1) {
        this.strings1 = strings1;
    }

    public Double[] getDoubles1() {
        return doubles1;
    }

    public void setDoubles1(Double[] doubles1) {
        this.doubles1 = doubles1;
    }

    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }

    public Long getNum() {
        return num;
    }

    public void setNum(Long num) {
        this.num = num;
    }

    public Long getAmount() {
        return amount;
    }

    public void setAmount(Long amount) {
        this.amount = amount;
    }

    public String getWeight() {
        return weight;
    }

    public void setWeight(String weight) {
        this.weight = weight;
    }

    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }
}

==> ejc-bpmdesktop-api-3.0.0-20251010.033421-149-sources.jar: com/ejianc/business/desktop/vo/UserInfoVO.java <==
package com.ejianc.business.desktop.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 流程主题门户接口
 * 
 * @author generator
 * 
 */
public class UserInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String materialCategoryName;
    private Long num;
    private  Long amount;
    private String weight;
    private String materialUnitName;
    private String[] strings1;
    private Double[] doubles1;
    private  Long userId;


    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String[] getStrings1() {
        return strings1;
    }

    public void setStrings1(String[] strings1) {
        this.strings1 = strings1;
    }

    public Double[] getDoubles1() {
        return doubles1;
    }

    public void setDoubles1(Double[] doubles1) {
        this.doubles1 = doubles1;
    }

    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }

    public Long getNum() {
        return num;
    }

    public void setNum(Long num) {
        this.num = num;
    }

    public Long getAmount() {
        return amount;
    }

    public void setAmount(Long amount) {
        this.amount = amount;
    }

    public String getWeight() {
        return weight;
    }

    public void setWeight(String weight) {
        this.weight = weight;
    }

    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }
}
